@@ -5,6 +5,6 @@ from dataclasses_json import DataClassJsonMixin
 
 @dataclass
 class Dependency(DataClassJsonMixin):
-    name: str
-    host: str
-    port: int
+    name: str = 'dependency'
+    host: str = '0.0.0.0'
+    port: int = 8080
